pub struct LockfileParser;Expand description
Parser for various lock files to get installed versions
Implementations
Sourceimpl LockfileParser
impl LockfileParser
pub fn new() -> Self
Sourcepub fn parse(&self, path: &PathBuf) -> Result<HashMap<String, Version>>
pub fn parse(&self, path: &PathBuf) -> Result<HashMap<String, Version>>
Parse a lock file and return a map of package name -> installed version