pub struct Version {
pub major: u64,
pub minor: u64,
pub patch: u64,
pub pre_release: Option<String>,
pub local: Option<String>,
pub original: String,
}Expand description
A parsed semantic version
Fields
major: u64minor: u64patch: u64pre_release: Option<String>local: Option<String>original: StringOriginal string representation
Implementations
Sourceimpl Version
impl Version
pub fn new(major: u64, minor: u64, patch: u64) -> Self
Sourcepub fn is_prerelease(&self) -> bool
pub fn is_prerelease(&self) -> bool
Check if this is a pre-release version
Sourcepub fn same_major(&self, other: &Version) -> bool
pub fn same_major(&self, other: &Version) -> bool
Check if this version is in the same major series as another
Sourcepub fn same_minor(&self, other: &Version) -> bool
pub fn same_minor(&self, other: &Version) -> bool
Check if this version is in the same minor series as another